jaclearn.rl.proxy
=================

.. automodule:: jaclearn.rl.proxy

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      AutoRestartProxy
      HistoryFrameProxy
      LimitLengthProxy
      MapActionProxy
      MapStateProxy
      NOPFillProxy
      RepeatActionProxy
      TransparentAttributeProxy
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      find_proxy
      manipulate_reward
      remove_proxies
   
   

   
   
   








.. rubric:: Class AutoRestartProxy
.. autoclass:: AutoRestartProxy
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class HistoryFrameProxy
.. autoclass:: HistoryFrameProxy
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class LimitLengthProxy
.. autoclass:: LimitLengthProxy
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MapActionProxy
.. autoclass:: MapActionProxy
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MapStateProxy
.. autoclass:: MapStateProxy
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class NOPFillProxy
.. autoclass:: NOPFillProxy
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class RepeatActionProxy
.. autoclass:: RepeatActionProxy
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class TransparentAttributeProxy
.. autoclass:: TransparentAttributeProxy
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: find_proxy

.. autofunction:: manipulate_reward

.. autofunction:: remove_proxies


